==> google_cloud_batch-0.3.2-py2.py3-none-any.whl: google/cloud/batch_v1alpha/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .batch import (
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    GetTaskRequest,
    ListJobsRequest,
    ListJobsResponse,
    ListTasksRequest,
    ListTasksResponse,
    OperationMetadata,
)
from .job import (
    AllocationPolicy,
    Job,
    JobDependency,
    JobNotification,
    JobStatus,
    LogsPolicy,
    ServiceAccount,
    TaskGroup,
)
from .task import (
    ComputeResource,
    Environment,
    LifecyclePolicy,
    Runnable,
    StatusEvent,
    Task,
    TaskExecution,
    TaskSpec,
    TaskStatus,
)
from .volume import (
    GCS,
    NFS,
    PD,
    Volume,
)

__all__ = (
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "GetTaskRequest",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "OperationMetadata",
    "AllocationPolicy",
    "Job",
    "JobDependency",
    "JobNotification",
    "JobStatus",
    "LogsPolicy",
    "ServiceAccount",
    "TaskGroup",
    "ComputeResource",
    "Environment",
    "LifecyclePolicy",
    "Runnable",
    "StatusEvent",
    "Task",
    "TaskExecution",
    "TaskSpec",
    "TaskStatus",
    "GCS",
    "NFS",
    "PD",
    "Volume",
)

==> google_cloud_batch-0.13.0-py2.py3-none-any.whl: google/cloud/batch_v1alpha/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .batch import (
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    GetTaskRequest,
    ListJobsRequest,
    ListJobsResponse,
    ListTasksRequest,
    ListTasksResponse,
    OperationMetadata,
)
from .job import (
    AllocationPolicy,
    Job,
    JobDependency,
    JobNotification,
    JobStatus,
    LogsPolicy,
    ResourceUsage,
    ServiceAccount,
    TaskGroup,
)
from .task import (
    ComputeResource,
    Environment,
    LifecyclePolicy,
    Runnable,
    StatusEvent,
    Task,
    TaskExecution,
    TaskResourceUsage,
    TaskSpec,
    TaskStatus,
)
from .volume import GCS, NFS, PD, Volume

__all__ = (
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "GetTaskRequest",
    "ListJobsRequest",
    "ListJobsResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "OperationMetadata",
    "AllocationPolicy",
    "Job",
    "JobDependency",
    "JobNotification",
    "JobStatus",
    "LogsPolicy",
    "ResourceUsage",
    "ServiceAccount",
    "TaskGroup",
    "ComputeResource",
    "Environment",
    "LifecyclePolicy",
    "Runnable",
    "StatusEvent",
    "Task",
    "TaskExecution",
    "TaskResourceUsage",
    "TaskSpec",
    "TaskStatus",
    "GCS",
    "NFS",
    "PD",
    "Volume",
)
